package Pcore::Firebird v1.0.0;

use Pcore -dist;

1;
__END__
=pod

=encoding utf8

=head1 NAME

Pcore::Firebird

=head1 SYNOPSIS

=head1 DESCRIPTION

=head1 ATTRIBUTES

=head1 METHODS

=head1 SEE ALSO

=head1 AUTHOR

zdm <zdm@softvisio.net>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020 by zdm.

=cut
